==> green-core-1.65.1.tgz: package/components/textarea/index.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.7EFAID3T.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.MREOOCNI.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.BMZFQH6M.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.4RWBFFF4.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.LI7D4K6V.js";
import "../../chunks/chunk.WFKUYHQY.js";
import "../../chunks/chunk.NDFBELXT.js";
import "../../chunks/chunk.K4KPKUH4.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.FGEL7RKS.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.TWPJWAVJ.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.BOM2WG3F.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.7WOX76ML.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};

==> green-core-1.68.0.tgz: package/components/textarea/index.js <==
import {
  GdsTextarea
} from "../../chunks/chunk.ULXGQJ44.js";
import "../../chunks/chunk.VHN4JEZC.js";
import "../../chunks/chunk.VZTV63IQ.js";
import "../../chunks/chunk.VHLWBCJK.js";
import "../../chunks/chunk.HO2KZJXR.js";
import "../../chunks/chunk.7GC6JLT5.js";
import "../../chunks/chunk.2BJVQ5WE.js";
import "../../chunks/chunk.YNWJYO4Y.js";
import "../../chunks/chunk.S3FBHJYG.js";
import "../../chunks/chunk.H4QXCNY2.js";
import "../../chunks/chunk.IVRW42EY.js";
import "../../chunks/chunk.ALFDKEVN.js";
import "../../chunks/chunk.DMM5QQ6O.js";
import "../../chunks/chunk.GUAH7AIO.js";
import "../../chunks/chunk.CK2UGCPG.js";
import "../../chunks/chunk.5EWN7LDC.js";
import "../../chunks/chunk.3M4XRCEF.js";
import "../../chunks/chunk.TO7VMB6K.js";
import "../../chunks/chunk.M5C2HLKD.js";
import "../../chunks/chunk.BCIZMK2U.js";
import "../../chunks/chunk.JGTSJ4J6.js";
import "../../chunks/chunk.LPLK7FFY.js";
import "../../chunks/chunk.TX64TTBN.js";
import "../../chunks/chunk.X6BMBAAE.js";
import "../../chunks/chunk.VA6TUMR2.js";
import "../../chunks/chunk.WM7HBMMV.js";
import "../../chunks/chunk.TWXTKG4B.js";
import "../../chunks/chunk.76QWARGM.js";
import "../../chunks/chunk.NUUST5OZ.js";
import "../../chunks/chunk.EUES6BVY.js";
import "../../chunks/chunk.TYGMNHNO.js";
import "../../chunks/chunk.FI4AQLJC.js";
import "../../chunks/chunk.6QMJ7GQK.js";
import "../../chunks/chunk.YO24ZYAD.js";
import "../../chunks/chunk.TMEWQZER.js";
import "../../chunks/chunk.QK3R23GV.js";
import "../../chunks/chunk.B7ZOSVCQ.js";
import "../../chunks/chunk.SEHSDSX2.js";
export {
  GdsTextarea
};
